==> arrow-docs-0.8.1-sources.jar: arrow/optics/Shape.Rectangle$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Shape`.`Rectangle`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Shape`.`Rectangle`, arrow.core.Tuple2<`kotlin`.`Double`, `kotlin`.`Double`>> inline get()= arrow.optics.Iso(
  get = { rectangle: `arrow`.`optics`.`Shape`.`Rectangle` -> arrow.core.Tuple2(rectangle.`width`, rectangle.`height`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Double`, `kotlin`.`Double`> -> `arrow`.`optics`.`Shape`.`Rectangle`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Shape`.`Rectangle`.Companion.width: arrow.optics.Lens<`arrow`.`optics`.`Shape`.`Rectangle`, `kotlin`.`Double`> inline get()= arrow.optics.Lens(
  get = { rectangle: `arrow`.`optics`.`Shape`.`Rectangle` -> rectangle.`width` },
  set = { value: `kotlin`.`Double` ->
    { rectangle: `arrow`.`optics`.`Shape`.`Rectangle` ->
      rectangle.copy(`width` = value)
    }
  }
)

inline val `arrow`.`optics`.`Shape`.`Rectangle`.Companion.height: arrow.optics.Lens<`arrow`.`optics`.`Shape`.`Rectangle`, `kotlin`.`Double`> inline get()= arrow.optics.Lens(
  get = { rectangle: `arrow`.`optics`.`Shape`.`Rectangle` -> rectangle.`height` },
  set = { value: `kotlin`.`Double` ->
    { rectangle: `arrow`.`optics`.`Shape`.`Rectangle` ->
      rectangle.copy(`height` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Getter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Setter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Traversal<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Fold<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Getter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Setter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Traversal<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Fold<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height

==> arrow-docs-0.10.4-sources.jar: arrow/optics/Shape.Rectangle$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Shape`.`Rectangle`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Shape`.`Rectangle`, arrow.core.Tuple2<`kotlin`.`Double`, `kotlin`.`Double`>> inline get()= arrow.optics.Iso(
  get = { rectangle: `arrow`.`optics`.`Shape`.`Rectangle` -> arrow.core.Tuple2(rectangle.`width`, rectangle.`height`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Double`, `kotlin`.`Double`> -> `arrow`.`optics`.`Shape`.`Rectangle`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Shape`.`Rectangle`.Companion.width: arrow.optics.Lens<`arrow`.`optics`.`Shape`.`Rectangle`, `kotlin`.`Double`> inline get()= arrow.optics.Lens(
  get = { rectangle: `arrow`.`optics`.`Shape`.`Rectangle` -> rectangle.`width` },
  set = { rectangle: `arrow`.`optics`.`Shape`.`Rectangle`, value: `kotlin`.`Double` -> rectangle.copy(`width` = value) }
)

inline val `arrow`.`optics`.`Shape`.`Rectangle`.Companion.height: arrow.optics.Lens<`arrow`.`optics`.`Shape`.`Rectangle`, `kotlin`.`Double`> inline get()= arrow.optics.Lens(
  get = { rectangle: `arrow`.`optics`.`Shape`.`Rectangle` -> rectangle.`height` },
  set = { rectangle: `arrow`.`optics`.`Shape`.`Rectangle`, value: `kotlin`.`Double` -> rectangle.copy(`height` = value) }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Getter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Setter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Traversal<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Shape`.`Rectangle`>.width: arrow.optics.Fold<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.width

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Getter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Setter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Traversal<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Shape`.`Rectangle`>.height: arrow.optics.Fold<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Rectangle`.height
